/*============================================================================*/
/* phpSysInfoTest.cmd                                                         */
/*                                                                            */
/* Runs test of info that can be retrieved with phpSysInfo.cmd.  Plus some    */
/* other tests to show that all the details that phpSysInfo displays.         */
/*                                                                            */
/* From phpSysInfo.cmd we get:                                                */
/*   - RAM      - Free memory.                                                */
/*   - SWAP     - Analysis of swapfile contents                               */
/*   - SWAPFILE - Size of swapfile.                                           */
/*   - NETWORK  - Network usage stats.                                        */
/*   - DISK     - Disk usage from df.exe.                                     */
/*   - KERNEL   - Kernel Build Level Information                              */
/*                                                                            */
/* The extra information is:                                                  */
/*   - RMVIEW                                                                 */
/*                                                                            */
/*============================================================================*/
/*                                                                            */
/* Copyright David Forrester 2002                                             */
/* Created:  12/03/2002                                                       */
/*                                                                            */
/*============================================================================*/

Trace 'Off'

Call LoadRxFuncs
Say "phpSysInfoTest.cmd - Collecting details of system."
Call GetHostName
Call PrintDivider
Call PrintDivider
Call LoadTCPFuncs
Call PrintDivider
Call GetDiskInfo
Call PrintDivider
Call GetRAMInfo
Call PrintDivider
Call GetSWAPInfo
Call PrintDivider
Call GetSWAPFILEInfo
Call PrintDivider
Call GetKERNELInfo
Call PrintDivider
Call GetNETWORKInfo
Call PrintDivider
Call RunRMView
Call PrintDivider
Call PrintDivider

Say
Say "End of phpSysInfoTest.cmd."


EXIT


/* Utitlity functions to load the Rexx libraries. */
LoadRxFuncs:

If RxFuncQuery('SysLoadFuncs') then do
   Call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
   Call SysLoadFuncs
End /* If .. Then Do */

Return


LoadTCPFuncs:

Say 'Testing Loading of RxTCPMon functions'

If \RxFuncQuery('TcpDropFuncs') Then do
   Say '   TcpDropFuncs is registered, so will drop the functions.'
   rc = TcpDropFuncs()
   Say '      rc =' rc
End /* If .. Then Do */

If RxFuncQuery('TcpLoadFuncs') Then do
   Say '   Adding TcpLoadFuncs...'
   call RxFuncAdd 'TcpLoadFuncs','RxTCPMon','TcpLoadFuncs'
   Say '   Calling TcpLoadFuncs...'
   rc = TcpLoadFuncs()
   Say '      rc =' rc
End /* If .. Then Do */

Return

GetDiskInfo:

Say "Getting disk info..."
driveMap = SysDriveMap()
checkedDriveMap = ''
Say 'SysDriveMap is: "' || driveMap || '"'
Do i = 1 to Words(driveMap)
   thisDrive = Word(driveMap, i)
   driveInfo = Strip(SysDriveInfo(thisDrive))
   If driveInfo <> '' Then Do
      checkedDriveMap = checkedDriveMap thisDrive
   End /* If .. Then Do */
   Say 'SysDriveInfo for' thisDrive || ': "' || driveInfo || '"'
End /* Do .. To .. */
Say
Say 'Running: which df.exe'
'which df.exe'
If rc = 1024 Then Say '  "which" was not found.  There would have been a SYS1401 error displayed.'
Else If rc <> 0 Then Say '  which returned rc =' rc
Say
Say 'Running: phpSysInfo DISK'
Call phpSysInfo 'DISK'

Return

GetHostName:

hostname = Strip(Value('HOSTNAME', , 'OS2ENVIRONMENT'))
If hostname = '' then Say "The hostname for this system has not been set!"
Else Say "Hostname for this system is:" hostname

Return

RunRMVIEW:
Say
Say 'Running RMVIEW'
'RMVIEW'
Return

GetRAMInfo:
Say
Say 'Getting RAM info'
Say
Say 'Running: phpSysInfo RAM'
Call phpSysInfo 'RAM'
Return

GetSWAPInfo:
Say
Say 'Getting SWAP info'
Say
Say 'Running: phpSysInfo SWAP'
Call phpSysInfo 'SWAP'
Return

GetSWAPFILEInfo:
Say
Say "Getting SWAPFILE info (Note: The second number isn't correct)"
Say
Say 'Running: phpSysInfo SWAPFILE'
Call phpSysInfo 'SWAPFILE'
Return

GetNETWORKInfo:
Say
Say 'Getting NETWORK info'
Say
Say 'Running: phpSysInfo NETWORK'
Call phpSysInfo 'NETWORK'

Say
Say 'Running: NETSTAT -T'
'NETSTAT -T'
Return

GetKERNELInfo:
Say
Say "Getting KERNEL info"
Say
Say 'Running: phpSysInfo KERNEL'
Call phpSysInfo 'KERNEL'
Return



PrintDivider:
Say Right("", 40, "*")
Return
